@@ -21,24 +21,54 @@
  * gui.c - where the main window is created
  */
 
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
-#include <stdlib.h>
 
-#include "types.h"
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+/*
+ * Standard gettext macros.
+ */
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  undef _
+#  define _(String) dgettext (PACKAGE, String)
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#else
+#  define textdomain(String) (String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory) (Domain)
+#  define _(String) (String)
+#  define N_(String) (String)
+#endif
+
+#include <stdlib.h>
+#include <string.h>
+
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+
 #include "gui.h"
-#include "preferences.h"
-#include "net.h"
-#include "utils.h"
+#include "gui_aboutdialog.h"
+#include "gui_closedialog.h"
+#include "gui_logdialog.h"
+#include "gui_manualdialog.h"
+#include "gui_opendialog.h"
+#include "gui_settingsdialog.h"
 #include "history.h"
 #include "hyperlink.h"
-#include "gui_opendialog.h"
-#include "gui_logdialog.h"
-#include "gui_closedialog.h"
-#include "gui_aboutdialog.h"
-#include "gui_settingsdialog.h"
-#include "gui_manualdialog.h"
+#include "net.h"
+#include "preferences.h"
 #include "text.h"
+#include "types.h"
+#include "utils.h"
+
 
 extern preferencestype preferences;
 
@@ -88,7 +118,7 @@ static GtkActionEntry entries[] = {
 	{ "SettingsMenu", NULL, N_("_Settings") },
 	{ "HelpMenu", NULL, N_("H_elp") },
 	{ "HighMenu", NULL, N_("Highlights") },
-	
+
 	{ "Quit", GTK_STOCK_QUIT, N_("Quit"),
 		"<control>Q", "Quit Program", G_CALLBACK(on_quit_activate) },
 	{ "Open", GTK_STOCK_CONNECT, N_("Connect..."),
@@ -100,7 +130,7 @@ static GtkActionEntry entries[] = {
 	{ "Preferences", GTK_STOCK_PREFERENCES, N_("Preferences..."),
 		"<control>P", "Settings for xdx", G_CALLBACK(on_settings_activate) },
 	{ "Manual", GTK_STOCK_HELP, N_("Manual"),
-		"F1", "Read the manual", G_CALLBACK(on_manual_activate) },
+		"<control>H", "Read the manual", G_CALLBACK(on_manual_activate) },
 	{ "About", GTK_STOCK_HELP, N_("About"),
 		"<control>A", "About xdx", G_CALLBACK(on_about_activate) },
 };
@@ -108,9 +138,12 @@ static GtkActionEntry entries[] = {
 
 static GtkToggleActionEntry toggle_entries[] =
 {
+  /* TODO: activate F keys */
+/*  { "Keybar", NULL, N_("Function keys bar"), "<control>K", "Function keys on/off",
+   G_CALLBACK(on_fkeys_activate) }, */
   { "Reconnect", NULL, N_("Auto Reconnect"), "<control>R", "Auto Reconnect on/off",
    G_CALLBACK(on_reconnect_activate) },
-  { "Sidebar", NULL, N_("Chat sidebar"), "F4", "Chat sidebar on/off",
+  { "Sidebar", NULL, N_("Chat sidebar"), "<control>S", "Chat sidebar on/off",
    G_CALLBACK(on_sidebar_activate) },
 };
 
@@ -126,6 +159,8 @@ static const char *ui_description =
 "      <menuitem action='Close'/>"
 "    </menu>"
 "    <menu action='SettingsMenu'>"
+  /* TODO: activate F keys */
+/*"      <menuitem action='Keybar'/>" */
 "      <menuitem action='Reconnect'/>"
 "      <menuitem action='Sidebar'/>"
 "      <separator name='sep2'/>"
@@ -163,7 +198,9 @@ create_mainwindow (void)
     *highentry1, *highentry2, *highentry3, *highentry4, *highentry5,
     *highentry6, *highentry7, *highentry8, *highcheck1, *highcheck2,
     *highcheck3, *highcheck4, *highcheck5, *highcheck6, *highcheck7,
-    *highcheck8, *soundcheck;
+    *highcheck8, *soundcheck,
+    *f1button, *f2button, *f3button, *f4button, *f5button,
+    *f6button, *f7button, *f8button, *fvbox, *fhbox1, *fhbox2;
   GtkCellRenderer *renderer, *boldrenderer, *greyrenderer;
   GtkTreeViewColumn *column;
   GtkTextBuffer *buffer, *entrybuffer;
@@ -202,6 +239,29 @@ create_mainwindow (void)
   get_main_menu (gui->window, &mainmenubar);
   gtk_container_add (GTK_CONTAINER (handlebox), mainmenubar);
 
+  fvbox = gtk_vbox_new (TRUE, 0);
+  fhbox1 = gtk_hbox_new (TRUE, 0);
+  fhbox2 = gtk_hbox_new (TRUE, 0);
+  gtk_container_add (GTK_CONTAINER (fvbox), fhbox1);
+  gtk_container_add (GTK_CONTAINER (fvbox), fhbox2);
+  f1button = gtk_button_new_with_label ("");
+  f2button = gtk_button_new_with_label ("");
+  f3button = gtk_button_new_with_label ("");
+  f4button = gtk_button_new_with_label ("");
+  gtk_container_add (GTK_CONTAINER (fhbox1), f1button);
+  gtk_container_add (GTK_CONTAINER (fhbox1), f2button);
+  gtk_container_add (GTK_CONTAINER (fhbox1), f3button);
+  gtk_container_add (GTK_CONTAINER (fhbox1), f4button);
+  f5button = gtk_button_new_with_label ("");
+  f6button = gtk_button_new_with_label ("");
+  f7button = gtk_button_new_with_label ("");
+  f8button = gtk_button_new_with_label ("");
+  gtk_container_add (GTK_CONTAINER (fhbox2), f5button);
+  gtk_container_add (GTK_CONTAINER (fhbox2), f6button);
+  gtk_container_add (GTK_CONTAINER (fhbox2), f7button);
+  gtk_container_add (GTK_CONTAINER (fhbox2), f8button);
+  gtk_box_pack_start (GTK_BOX (mainvbox), fvbox, FALSE, TRUE, 0);
+
   clistscrolledwindow = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (clistscrolledwindow),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
@@ -221,7 +281,7 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes (_("Spotter"), renderer, "text",
 					      FROM_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -229,7 +289,7 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes ("QRG", renderer, "text",
 					      FREQ_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable (GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -237,7 +297,7 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes ("DX", boldrenderer, "text",
 					      DX_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -245,7 +305,7 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes (_("Remarks"), renderer, "text",
 					      REM_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -253,7 +313,7 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes (_("Time"), renderer, "text",
 					      TIME_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -261,20 +321,20 @@ create_mainwindow (void)
   column =
     gtk_tree_view_column_new_with_attributes (_("Info"), renderer, "text",
 						INFO_COLUMN, NULL);
-  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-	
+
 	column =
    gtk_tree_view_column_new_with_attributes (_("Country"), greyrenderer, "text",
 						COUNTRY_COLUMN, NULL);
   g_object_set(G_OBJECT(greyrenderer), "cell-background", "grey", NULL);
-  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column), 
+  gtk_tree_view_column_set_sizing(GTK_TREE_VIEW_COLUMN(column),
     GTK_TREE_VIEW_COLUMN_FIXED);
   gtk_tree_view_column_set_resizable(GTK_TREE_VIEW_COLUMN(column), TRUE);
   gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
-		
+
   gtk_container_add (GTK_CONTAINER (clistscrolledwindow), treeview);
 
   chathbox = gtk_hbox_new (FALSE, 0);
@@ -286,7 +346,7 @@ create_mainwindow (void)
   gtk_container_add (GTK_CONTAINER (mainscrolledwindow), maintext);
   gtk_text_view_set_editable (GTK_TEXT_VIEW (maintext), FALSE);
   buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (maintext));
-  gtk_text_buffer_create_tag (buffer, "url", "foreground", "blue", 
+  gtk_text_buffer_create_tag (buffer, "url", "foreground", "blue",
     "underline", PANGO_UNDERLINE_SINGLE, NULL);
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (maintext), GTK_WRAP_WORD);
   gtk_box_pack_start (GTK_BOX (chathbox), mainscrolledwindow, TRUE, TRUE, 0);
@@ -421,6 +481,15 @@ create_mainwindow (void)
   str = g_strdup_printf (_("Enable/disable sound [Ctrl+%d]"), 0);
   gtk_widget_set_tooltip_text(soundcheck, str);
 
+  gtk_widget_set_tooltip_text(f1button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f2button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f3button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f4button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f5button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f6button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f7button, _("Right click to edit"));
+  gtk_widget_set_tooltip_text(f8button, _("Right click to edit"));
+
   mainentry = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(mainentry), GTK_WRAP_WORD);
   frame = gtk_frame_new (NULL);
@@ -507,6 +576,40 @@ create_mainwindow (void)
   g_signal_connect (G_OBJECT (highentry8), "button_press_event",
         G_CALLBACK (on_highentry_clicked), NULL);
 
+  g_signal_connect (G_OBJECT (f1button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(1));
+  g_signal_connect (G_OBJECT (f2button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(2));
+  g_signal_connect (G_OBJECT (f3button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(3));
+  g_signal_connect (G_OBJECT (f4button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(4));
+  g_signal_connect (G_OBJECT (f5button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(5));
+  g_signal_connect (G_OBJECT (f6button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(6));
+  g_signal_connect (G_OBJECT (f7button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(7));
+  g_signal_connect (G_OBJECT (f8button), "clicked",
+        G_CALLBACK (on_fbutton_clicked), GINT_TO_POINTER(8));
+
+  g_signal_connect (G_OBJECT(f1button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(1));
+  g_signal_connect (G_OBJECT(f2button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(2));
+  g_signal_connect (G_OBJECT(f3button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(3));
+  g_signal_connect (G_OBJECT(f4button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(4));
+  g_signal_connect (G_OBJECT(f5button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(5));
+  g_signal_connect (G_OBJECT(f6button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(6));
+  g_signal_connect (G_OBJECT(f7button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(7));
+  g_signal_connect (G_OBJECT(f8button), "button-press-event",
+			 G_CALLBACK (on_fbutton_press), GINT_TO_POINTER(8));
+
   g_object_set_data (G_OBJECT (gui->window), "maintext", maintext);
   g_object_set_data (G_OBJECT (gui->window), "treeview", treeview);
   g_object_set_data (G_OBJECT (gui->window), "mainstatusbar", mainstatusbar);
@@ -532,6 +635,15 @@ create_mainwindow (void)
   g_object_set_data (G_OBJECT (gui->window), "highentry7", highentry7);
   g_object_set_data (G_OBJECT (gui->window), "highentry8", highentry8);
   g_object_set_data (G_OBJECT (gui->window), "highframe", highframe);
+  g_object_set_data (G_OBJECT (gui->window), "fvbox", fvbox);
+  g_object_set_data (G_OBJECT (gui->window), "f1button", f1button);
+  g_object_set_data (G_OBJECT (gui->window), "f2button", f2button);
+  g_object_set_data (G_OBJECT (gui->window), "f3button", f3button);
+  g_object_set_data (G_OBJECT (gui->window), "f4button", f4button);
+  g_object_set_data (G_OBJECT (gui->window), "f5button", f5button);
+  g_object_set_data (G_OBJECT (gui->window), "f6button", f6button);
+  g_object_set_data (G_OBJECT (gui->window), "f7button", f7button);
+  g_object_set_data (G_OBJECT (gui->window), "f8button", f8button);
 
   cluster = new_cluster();
   g_object_set_data(G_OBJECT (gui->window), "cluster", cluster);
@@ -648,7 +760,7 @@ static void cleanup (void)
 	}
   g_list_free(gui->hostnamehistory);
   gui->hostnamehistory = NULL;
-	
+
   link = gui->porthistory;
   while (link)
 	{
@@ -666,7 +778,7 @@ static void cleanup (void)
 	}
   g_list_free(gui->txhistory);
   gui->txhistory = NULL;
-	
+
   g_free(gui->preferencesdir);
   gui->preferencesdir = NULL;
   g_free(gui->statusbarmessage);
@@ -711,6 +823,28 @@ on_quit_activate (GtkMenuItem * menuitem, gpointer user_data)
   gtk_main_quit ();
 }
 
+void on_fkeys_activate (GtkAction * action, gpointer user_data)
+{
+  GtkWidget *fkeysmenu, *fvbox;;
+  gboolean state;
+
+  fkeysmenu = gtk_ui_manager_get_widget
+    (gui->ui_manager, "/MainMenu/SettingsMenu/Keybar");
+  state = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(fkeysmenu));
+  fvbox = g_object_get_data (G_OBJECT (gui->window), "fvbox");
+
+  if (state)
+  {
+  	preferences.fbox = 1;
+  	gtk_widget_show (fvbox);
+  }
+  else
+  {
+  	preferences.fbox = 0;
+  	gtk_widget_hide (fvbox);
+  }
+}
+
 void on_reconnect_activate (GtkAction * action, gpointer user_data)
 {
   GtkWidget *reconnectmenu;
@@ -799,6 +933,12 @@ void on_highentry_changed (GtkEditable * editable, gpointer user_data)
   g_free (high);
 }
 
+void
+on_fbutton_clicked (GtkButton *button, gpointer user_data)
+{
+	g_print("%d ", GPOINTER_TO_INT(user_data));
+}
+
 gboolean on_highentry_clicked
 (GtkEditable * entry, GdkEventButton *event, gpointer user_data)
 {
@@ -831,17 +971,18 @@ on_mainwindow_destroy_event (GtkWidget * widget, GdkEvent * event,
 }
 
 
-/* 
- * history of the entry widget 
+/*
+ * history of the entry widget
  */
 gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event,
 					 gpointer user_data)
 {
 
-  GtkWidget *mainentry;
+  GtkWidget *mainentry, *f1button, *f2button, *f3button, *f4button,
+    *f5button, *f6button, *f7button, *f8button;
 
   mainentry = g_object_get_data (G_OBJECT (gui->window), "mainentry");
-  if (GTK_WIDGET_HAS_FOCUS(mainentry))
+  if (gtk_widget_has_focus(mainentry))
   {
     switch (event->keyval)
     {
@@ -857,12 +998,171 @@ gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event,
       break;
     }
   }
+  switch (event->keyval)
+  {
+      case GDK_F1:
+        f1button = g_object_get_data (G_OBJECT (gui->window), "f1button");
+        g_signal_emit_by_name (G_OBJECT (f1button), "activate");
+      break;
+      case GDK_F2:
+        f2button = g_object_get_data (G_OBJECT (gui->window), "f2button");
+        g_signal_emit_by_name (G_OBJECT (f2button), "activate");
+      break;
+      case GDK_F3:
+        f3button = g_object_get_data (G_OBJECT (gui->window), "f3button");
+        g_signal_emit_by_name (G_OBJECT (f3button), "activate");
+      break;
+      case GDK_F4:
+        f4button = g_object_get_data (G_OBJECT (gui->window), "f4button");
+        g_signal_emit_by_name (G_OBJECT (f4button), "activate");
+      break;
+      case GDK_F5:
+        f5button = g_object_get_data (G_OBJECT (gui->window), "f5button");
+        g_signal_emit_by_name (G_OBJECT (f5button), "activate");
+      break;
+      case GDK_F6:
+        f6button = g_object_get_data (G_OBJECT (gui->window), "f6button");
+        g_signal_emit_by_name (G_OBJECT (f6button), "activate");
+      break;
+      case GDK_F7:
+        f7button = g_object_get_data (G_OBJECT (gui->window), "f7button");
+        g_signal_emit_by_name (G_OBJECT (f7button), "activate");
+      break;
+      case GDK_F8:
+        f8button = g_object_get_data (G_OBJECT (gui->window), "f8button");
+        g_signal_emit_by_name (G_OBJECT (f8button), "activate");
+      break;
+      default:
+      break;
+  }
   return FALSE;
 }
 
-gboolean 
+gboolean
+on_fbutton_press (GtkButton *button, GdkEventButton *event, gpointer user_data)
+{
+	GtkWidget *editdialog, *editvbox, *editlabel, *editentry,
+	  *f1button, *f2button, *f3button, *f4button, *f5button, *f6button,
+      *f7button, *f8button;
+	gchar *temp, *str;
+	gint response;
+
+	if (event->button == 3)
+	{
+	  editdialog = gtk_dialog_new_with_buttons (_("xdx - edit function key"),
+	    GTK_WINDOW (gui->window), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+	    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+      editvbox = gtk_vbox_new (TRUE, 0);
+      gtk_box_pack_start (GTK_BOX (GTK_DIALOG (editdialog)->vbox),
+		editvbox, TRUE, TRUE, 0);
+      temp = g_strdup_printf (_("Command to be used for F%d"), GPOINTER_TO_INT(user_data));
+	  editlabel = gtk_label_new_with_mnemonic (temp);
+	  g_free (temp);
+	  gtk_box_pack_start (GTK_BOX (editvbox), editlabel, TRUE, TRUE, 0);
+	  editentry = gtk_entry_new ();
+	  gtk_box_pack_start (GTK_BOX (editvbox), editentry, TRUE, TRUE, 0);
+
+      if (GPOINTER_TO_INT(user_data) == 1 && strcmp(preferences.f1command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f1command);
+      if (GPOINTER_TO_INT(user_data) == 2 && strcmp(preferences.f2command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f2command);
+      if (GPOINTER_TO_INT(user_data) == 3 && strcmp(preferences.f3command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f3command);
+      if (GPOINTER_TO_INT(user_data) == 4 && strcmp(preferences.f4command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f4command);
+      if (GPOINTER_TO_INT(user_data) == 5 && strcmp(preferences.f5command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f5command);
+      if (GPOINTER_TO_INT(user_data) == 6 && strcmp(preferences.f6command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f6command);
+      if (GPOINTER_TO_INT(user_data) == 7 && strcmp(preferences.f7command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f7command);
+      if (GPOINTER_TO_INT(user_data) == 8 && strcmp(preferences.f8command, "^"))
+        gtk_entry_set_text (GTK_ENTRY(editentry), preferences.f8command);
+
+	  gtk_widget_show_all (editdialog);
+	  response = gtk_dialog_run (GTK_DIALOG (editdialog));
+      if (response == GTK_RESPONSE_OK)
+      {
+      	temp = gtk_editable_get_chars (GTK_EDITABLE (editentry), 0, -1);
+      	if (strlen(temp) > 0)
+      	{
+      	  if (GPOINTER_TO_INT(user_data) == 1)
+      	  {
+      	    f1button = g_object_get_data (G_OBJECT (gui->window), "f1button");
+            preferences.f1command = g_strdup (temp);
+            str = g_strdup_printf ("F1: %s", preferences.f1command);
+            gtk_button_set_label (GTK_BUTTON (f1button), str);
+            g_free (str);
+
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 2)
+      	  {
+      	    f2button = g_object_get_data (G_OBJECT (gui->window), "f2button");
+      	    preferences.f2command = g_strdup (temp);
+            str = g_strdup_printf ("F2: %s", preferences.f2command);
+            gtk_button_set_label (GTK_BUTTON (f2button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 3)
+      	  {
+      	    f3button = g_object_get_data (G_OBJECT (gui->window), "f3button");
+      	    preferences.f3command = g_strdup (temp);
+            str = g_strdup_printf ("F3: %s", preferences.f3command);
+            gtk_button_set_label (GTK_BUTTON (f3button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 4)
+      	  {
+      	    f4button = g_object_get_data (G_OBJECT (gui->window), "f4button");
+      	    preferences.f4command = g_strdup (temp);
+            str = g_strdup_printf ("F4: %s", preferences.f4command);
+            gtk_button_set_label (GTK_BUTTON (f4button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 5)
+      	  {
+      	    f5button = g_object_get_data (G_OBJECT (gui->window), "f5button");
+      	    preferences.f5command = g_strdup (temp);
+            str = g_strdup_printf ("F5: %s", preferences.f5command);
+            gtk_button_set_label (GTK_BUTTON (f5button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 6)
+      	  {
+      	    f6button = g_object_get_data (G_OBJECT (gui->window), "f6button");
+      	    preferences.f6command = g_strdup (temp);
+            str = g_strdup_printf ("F6: %s", preferences.f6command);
+            gtk_button_set_label (GTK_BUTTON (f6button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 7)
+      	  {
+      	    f7button = g_object_get_data (G_OBJECT (gui->window), "f7button");
+      	    preferences.f7command = g_strdup (temp);
+            str = g_strdup_printf ("F7: %s", preferences.f7command);
+            gtk_button_set_label (GTK_BUTTON (f7button), str);
+            g_free (str);
+          }
+      	  if (GPOINTER_TO_INT(user_data) == 8)
+      	  {
+      	    f8button = g_object_get_data (G_OBJECT (gui->window), "f8button");
+      	    preferences.f8command = g_strdup (temp);
+            str = g_strdup_printf ("F8: %s", preferences.f8command);
+            gtk_button_set_label (GTK_BUTTON (f8button), str);
+            g_free (str);
+          }
+		}
+		g_free (temp);
+      }
+	  gtk_widget_destroy (editdialog);
+	  return TRUE;
+	}
+	return FALSE;
+}
+
+gboolean
 double_click (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
-{  
+{
   GtkTreeIter selected;
   GtkTreeModel *model;
   gchar *getf, **fsplit, *hamlibstr;
