@@ -21,4 +21,10 @@
  * gui_logdialog.h
  */
 
+
+#ifndef XDX_GUI_LOGDIALOG_H
+#define XDX_GUI_LOGDIALOG_H
+
 void on_log_activate (GtkMenuItem * menuitem, gpointer user_data);
+
+#endif /* XDX_GUI_LOGDIALOG_H */
