@@ -21,13 +21,43 @@
  * preferences.c - private functions for saving and recalling xdx preferences.
  */
 
-#include <gtk/gtk.h>
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+/*
+ * Standard gettext macros.
+ */
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  undef _
+#  define _(String) dgettext (PACKAGE, String)
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#else
+#  define textdomain(String) (String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory) (Domain)
+#  define _(String) (String)
+#  define N_(String) (String)
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/stat.h>
+
+#include <gtk/gtk.h>
+
+#include "gui.h"
 #include "preferences.h"
 #include "utils.h"
-#include "gui.h"
+
 
 preferencestype preferences;
 
@@ -64,7 +94,7 @@ loadpreferences (void)
   preferences.y = 30;
   preferences.width = 750;
   preferences.height = 550;
-  preferences.columnwidths = 
+  preferences.columnwidths =
     g_strdup_printf("%d,%d,%d,%d,%d,%d,%d",
     COL0WIDTH, COL1WIDTH, COL2WIDTH, COL3WIDTH, COL4WIDTH, COL5WIDTH, COL6WIDTH);
   preferences.autologin = 0;
@@ -75,9 +105,9 @@ loadpreferences (void)
   preferences.savetoall = 0;
   preferences.savewx = 0;
   preferences.hamlib = 0;
-  preferences.rigctl = g_strdup("rigctl -m 1 set_freq %d");;
-  preferences.browserapp = g_strdup("firefox %s");
-  preferences.mailapp = g_strdup("evolution mailto:%s");
+  preferences.rigctl = g_strdup("rigctl -m 1 -r /dev/rig set_freq %d");;
+  preferences.browserapp = g_strdup("?");
+  preferences.mailapp = g_strdup("?");
   preferences.soundapp = g_strdup("play %s");
   preferences.col0visible = 1;
   preferences.col1visible = 1;
@@ -108,6 +138,7 @@ loadpreferences (void)
   gdk_color_parse("red", &preferences.highcolor8);
   preferences.highmenu = g_strdup ("00000000");
   preferences.sidebar = 1;
+  preferences.fbox = 1;
   preferences.reconnect = 0;
   preferences.playsound = 0;
   preferences.keepalive = 0;
@@ -115,7 +146,15 @@ loadpreferences (void)
   gdk_color_parse("red", &preferences.sentcolor);
   gdk_color_parse("darkgreen", &preferences.wwvcolor);
   gdk_color_parse("magenta", &preferences.wxcolor);
-  
+  preferences.f1command = g_strdup ("^");
+  preferences.f2command = g_strdup ("^");
+  preferences.f3command = g_strdup ("^");
+  preferences.f4command = g_strdup ("^");
+  preferences.f5command = g_strdup ("^");
+  preferences.f6command = g_strdup ("^");
+  preferences.f7command = g_strdup ("^");
+  preferences.f8command = g_strdup ("^");
+
   /* open preferences file */
   preferencesfile = g_strdup_printf ("%s/preferences", gui->preferencesdir);
   fp = fopen (preferencesfile, "r");
@@ -124,34 +163,34 @@ loadpreferences (void)
     while (!feof (fp))
       {
         if (fscanf (fp, "%s %s", label, value) == EOF) break;
-	      if (!g_ascii_strcasecmp(label, "x")) 
+	      if (!g_ascii_strcasecmp(label, "x"))
           preferences.x = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "y")) 
+        else if (!g_ascii_strcasecmp(label, "y"))
           preferences.y = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "width")) 
+        else if (!g_ascii_strcasecmp(label, "width"))
           preferences.width = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "height")) 
+        else if (!g_ascii_strcasecmp(label, "height"))
           preferences.height = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "columnwidths2")) 
+        else if (!g_ascii_strcasecmp(label, "columnwidths2"))
           preferences.columnwidths = g_strdup(value);
-        else if (!g_ascii_strcasecmp(label, "autologin")) 
+        else if (!g_ascii_strcasecmp(label, "autologin"))
           preferences.autologin = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "callsign")) 
+        else if (!g_ascii_strcasecmp(label, "callsign"))
           preferences.callsign = g_strdup(value);
         else if (!g_ascii_strcasecmp(label, "commands"))
         {
           g_strdelimit (value, "_", ' ');
           preferences.commands = g_strdup(value);
         }
-        else if (!g_ascii_strcasecmp(label, "savedx")) 
+        else if (!g_ascii_strcasecmp(label, "savedx"))
           preferences.savedx = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "savewwv")) 
+        else if (!g_ascii_strcasecmp(label, "savewwv"))
           preferences.savewwv = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "savetoall")) 
+        else if (!g_ascii_strcasecmp(label, "savetoall"))
           preferences.savetoall = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "savewx")) 
+        else if (!g_ascii_strcasecmp(label, "savewx"))
           preferences.savewx = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "hamlib")) 
+        else if (!g_ascii_strcasecmp(label, "hamlib"))
           preferences.hamlib = atoi(value);
         else if (!g_ascii_strcasecmp(label, "rigctl"))
         {
@@ -173,19 +212,19 @@ loadpreferences (void)
           g_strdelimit (value, "~", ' ');
           preferences.soundapp = g_strdup(value);
         }
-        else if (!g_ascii_strcasecmp(label, "col0visible")) 
+        else if (!g_ascii_strcasecmp(label, "col0visible"))
           preferences.col0visible = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "col1visible")) 
+        else if (!g_ascii_strcasecmp(label, "col1visible"))
           preferences.col1visible = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "col2visible")) 
+        else if (!g_ascii_strcasecmp(label, "col2visible"))
           preferences.col2visible = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "col3visible")) 
+        else if (!g_ascii_strcasecmp(label, "col3visible"))
           preferences.col3visible = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "col4visible")) 
+        else if (!g_ascii_strcasecmp(label, "col4visible"))
           preferences.col4visible = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "col5visible")) 
+        else if (!g_ascii_strcasecmp(label, "col5visible"))
           preferences.col5visible = atoi(value);
-	else if (!g_ascii_strcasecmp(label, "col6visible")) 
+        else if (!g_ascii_strcasecmp(label, "col6visible"))
           preferences.col6visible = atoi(value);
         else if (!g_ascii_strcasecmp(label, "dxfont"))
         {
@@ -197,9 +236,9 @@ loadpreferences (void)
           g_strdelimit (value, "~", ' ');
           preferences.allfont = g_strdup(value);
         }
-        else if (!g_ascii_strcasecmp(label, "localecho")) 
+        else if (!g_ascii_strcasecmp(label, "localecho"))
           preferences.localecho = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "handlebarpos")) 
+        else if (!g_ascii_strcasecmp(label, "handlebarpos"))
           preferences.handlebarpos = atoi(value);
         else if (!g_ascii_strcasecmp(label, "highword1"))
         {
@@ -241,40 +280,82 @@ loadpreferences (void)
           g_strdelimit (value, "~", ' ');
           preferences.highword8 = g_strdup(value);
         }
-	else if (!g_ascii_strcasecmp(label, "highcolor1"))
+        else if (!g_ascii_strcasecmp(label, "highcolor1"))
           gdk_color_parse(value, &preferences.highcolor1);
-	else if (!g_ascii_strcasecmp(label, "highcolor2"))
+        else if (!g_ascii_strcasecmp(label, "highcolor2"))
           gdk_color_parse(value, &preferences.highcolor2);
-	else if (!g_ascii_strcasecmp(label, "highcolor3"))
+        else if (!g_ascii_strcasecmp(label, "highcolor3"))
           gdk_color_parse(value, &preferences.highcolor3);
-	else if (!g_ascii_strcasecmp(label, "highcolor4"))
+        else if (!g_ascii_strcasecmp(label, "highcolor4"))
           gdk_color_parse(value, &preferences.highcolor4);
-	else if (!g_ascii_strcasecmp(label, "highcolor5"))
+        else if (!g_ascii_strcasecmp(label, "highcolor5"))
           gdk_color_parse(value, &preferences.highcolor5);
-	else if (!g_ascii_strcasecmp(label, "highcolor6"))
+        else if (!g_ascii_strcasecmp(label, "highcolor6"))
           gdk_color_parse(value, &preferences.highcolor6);
-	else if (!g_ascii_strcasecmp(label, "highcolor7"))
+        else if (!g_ascii_strcasecmp(label, "highcolor7"))
           gdk_color_parse(value, &preferences.highcolor7);
-	else if (!g_ascii_strcasecmp(label, "highcolor8"))
+        else if (!g_ascii_strcasecmp(label, "highcolor8"))
           gdk_color_parse(value, &preferences.highcolor8);
         else if (!g_ascii_strcasecmp(label, "highmenu"))
           preferences.highmenu = g_strdup(value);
-        else if (!g_ascii_strcasecmp(label, "sidebar")) 
+        else if (!g_ascii_strcasecmp(label, "sidebar"))
           preferences.sidebar = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "reconnect")) 
+        else if (!g_ascii_strcasecmp(label, "fbox"))
+          preferences.fbox = atoi(value);
+        else if (!g_ascii_strcasecmp(label, "reconnect"))
           preferences.reconnect = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "playsound")) 
+        else if (!g_ascii_strcasecmp(label, "playsound"))
           preferences.playsound = atoi(value);
-        else if (!g_ascii_strcasecmp(label, "keepalive")) 
+        else if (!g_ascii_strcasecmp(label, "keepalive"))
           preferences.keepalive = atoi(value);
-	else if (!g_ascii_strcasecmp(label, "promptcolor"))
+        else if (!g_ascii_strcasecmp(label, "promptcolor"))
           gdk_color_parse(value, &preferences.promptcolor);
-	else if (!g_ascii_strcasecmp(label, "sentcolor"))
+        else if (!g_ascii_strcasecmp(label, "sentcolor"))
           gdk_color_parse(value, &preferences.sentcolor);
-	else if (!g_ascii_strcasecmp(label, "wwvcolor"))
+        else if (!g_ascii_strcasecmp(label, "wwvcolor"))
           gdk_color_parse(value, &preferences.wwvcolor);
-	else if (!g_ascii_strcasecmp(label, "wxcolor"))
+        else if (!g_ascii_strcasecmp(label, "wxcolor"))
           gdk_color_parse(value, &preferences.wxcolor);
+        else if (!g_ascii_strcasecmp(label, "f1command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f1command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f2command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f2command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f3command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f3command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f4command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f4command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f5command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f5command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f6command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f6command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f7command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f7command = g_strdup(value);
+        }
+        else if (!g_ascii_strcasecmp(label, "f8command"))
+        {
+          g_strdelimit (value, "~", ' ');
+          preferences.f8command = g_strdup(value);
+        }
     }
     fclose (fp);
   }
@@ -404,6 +485,8 @@ savepreferences (void)
     fprintf(fp, "highmenu %s\n", str);
     str = g_strdup_printf("%d", preferences.sidebar);
     fprintf(fp, "sidebar %s\n", str);
+    str = g_strdup_printf("%d", preferences.fbox);
+    fprintf(fp, "fbox %s\n", str);
     str = g_strdup_printf("%d", preferences.reconnect);
     fprintf(fp, "reconnect %s\n", str);
     str = g_strdup_printf("%d", preferences.playsound);
@@ -418,9 +501,32 @@ savepreferences (void)
       preferences.wwvcolor.red, preferences.wwvcolor.green, preferences.wwvcolor.blue);
     fprintf(fp, "wxcolor #%04X%04X%04X\n",
       preferences.wxcolor.red, preferences.wxcolor.green, preferences.wxcolor.blue);
+    str = g_strdup_printf("%s", preferences.f1command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f1command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f2command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f2command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f3command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f3command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f4command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f4command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f5command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f5command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f6command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f6command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f7command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f7command %s\n", str);
+    str = g_strdup_printf("%s", preferences.f8command);
+    g_strdelimit (str, " ", '~');
+    fprintf(fp, "f8command %s\n", str);
     g_free(str);
     fclose (fp);
   }
   g_free(preferencesfile);
 }
-
