@@ -21,6 +21,10 @@
  * preferences.h
  */
 
+
+#ifndef XDX_PREFERENCES_H
+#define XDX_PREFERENCES_H
+
 #define COL0WIDTH 70
 #define COL1WIDTH 70
 #define COL2WIDTH 70
@@ -77,6 +81,7 @@ typedef struct
   GdkColor highcolor8;
   gchar *highmenu;
   gint sidebar;
+  gint fbox;
   gint reconnect;
   gint playsound;
   gint keepalive;
@@ -84,8 +89,18 @@ typedef struct
   GdkColor sentcolor;
   GdkColor wwvcolor;
   GdkColor wxcolor;
+  gchar *f1command;
+  gchar *f2command;
+  gchar *f3command;
+  gchar *f4command;
+  gchar *f5command;
+  gchar *f6command;
+  gchar *f7command;
+  gchar *f8command;
 } preferencestype;
 
 void dircheck (void);
 void loadpreferences (void);
 void savepreferences (void);
+
+#endif /* XDX_PREFERENCES_H */
