@@ -21,7 +21,13 @@
  *  save.h
  */
 
+
+#ifndef XDX_SAVE_H
+#define XDX_SAVE_H
+
 void savedx (gchar *dx);
 void savewwv (gchar *wwv);
 void savetoall (gchar *toall);
 void savewx (gchar *wx);
+
+#endif /* XDX_SAVE_H */
