@@ -18,21 +18,53 @@
  */
 
 /*
- * text.c - private functions for looking up and displaying text, either in a 
+ * text.c - private functions for looking up and displaying text, either in a
  * treeview or a textview
  */
 
-#include <gtk/gtk.h>
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+/*
+ * Standard gettext macros.
+ */
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  undef _
+#  define _(String) dgettext (PACKAGE, String)
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#else
+#  define textdomain(String) (String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory) (Domain)
+#  define _(String) (String)
+#  define N_(String) (String)
+#endif
+
+#include <errno.h>
 #include <string.h>
 #include <stdlib.h>
-#include "types.h"
-#include "utils.h"
-#include "text.h"
-#include "net.h"
+
+#include <gtk/gtk.h>
+#include <glib/gstdio.h>
+
 #include "gui.h"
+#include "gtksourceiter.h"
+#include "net.h"
 #include "preferences.h"
 #include "save.h"
-#include "gtksourceiter.h"
+#include "text.h"
+#include "types.h"
+#include "utils.h"
+
 
 GPtrArray *dxcc;
 GHashTable *prefixes;
@@ -40,7 +72,7 @@ gint excitu, exccq, countries;
 
 extern preferencestype preferences;
 
-typedef struct dxinfo 
+typedef struct dxinfo
 {
   gchar *spotter;
   gchar *freq;
@@ -54,12 +86,12 @@ typedef struct dxinfo
   gboolean nodx;
 } dxinfo;
 
-typedef struct 
+typedef struct
 {
   gchar *str;
   gchar *file;
 } smiley;
- 
+
 
 static dxinfo *dx;
 GSList *smileylist = NULL;
@@ -125,8 +157,8 @@ create_smiley_list (void)
 //  s = new_smiley (); s->str = "is"; s->file = PACKAGE_DATA_DIR "/pixmaps/sad.png"; smileylist = g_slist_append(smileylist, s);
 }
 
-/* 
- * extract call from dxmessage and return call and length of call 
+/*
+ * extract call from dxmessage and return call and length of call
  */
 static gchar *
 findcall (gchar * str, gint * spotterlen)
@@ -153,8 +185,8 @@ findcall (gchar * str, gint * spotterlen)
   return (str);
 }
 
-/* 
- * find the end of frequency and DX-call field 
+/*
+ * find the end of frequency and DX-call field
  */
 static gchar *
 findspace (gchar * str)
@@ -178,8 +210,8 @@ findspace (gchar * str)
   return (str);
 }
 
-/* 
- * find the end of frequency field 
+/*
+ * find the end of frequency field
  */
 static gchar *
 findfreq (gchar * str)
@@ -203,9 +235,9 @@ findfreq (gchar * str)
   return (str);
 }
 
-/* 
- * end of remarks field found if there is a space 
- * and the next 2 characters are digits 
+/*
+ * end of remarks field found if there is a space
+ * and the next 2 characters are digits
  */
 static gchar *
 findrem (gchar * str, gint * remlen)
@@ -236,8 +268,8 @@ findrem (gchar * str, gint * remlen)
 
 }
 
-/* 
- * search for the end of time field 
+/*
+ * search for the end of time field
  */
 static gchar *
 findtime (gchar * str)
@@ -261,8 +293,8 @@ findtime (gchar * str)
   return (str);
 }
 
-/* 
- * search for the end of the locator field 
+/*
+ * search for the end of the locator field
  */
 static gchar *
 findinfo (gchar * str)
@@ -318,7 +350,7 @@ static gchar* extractinfo(gchar *msg)
   gchar *dxmsg, *info, *ret;
   gint l;
 struct info lookup;
-	
+
   dx = new_dx();
   info = g_strdup(msg);
 
@@ -331,11 +363,11 @@ struct info lookup;
     dx->remark = g_strdup(findrem(dxmsg + 39, &l));
     dx->time = g_strdup(findtime(dxmsg + 39 + l));
     dx->info = g_strdup(findinfo(dxmsg + 45 + l));
-	  
+
     lookup = lookupcountry_by_callsign(dx->dxcall);
     dxcc_data *d = g_ptr_array_index (dxcc, lookup.country);
     dx->country = g_strdup(d->countryname);
-	  
+
     dx->toall = NULL;
     dx->dx = TRUE;
     dx->nodx = FALSE;
@@ -355,12 +387,12 @@ struct info lookup;
     dx->dx = FALSE;
     dx->nodx = TRUE;
   }
-  
+
   g_free(info);
 
   ret = strstr(msg, "\n");
   if (ret)
-    return (ret + 1); 
+    return (ret + 1);
   else
     return NULL;
 }
@@ -422,7 +454,7 @@ contains_highlights (gchar *str)
 }
 
 /* used when colorizing DX-cluster prompt */
-static gboolean 
+static gboolean
 findcolonprompt (gunichar ch, gpointer user_data)
 {
   switch (ch)
@@ -435,7 +467,7 @@ findcolonprompt (gunichar ch, gpointer user_data)
 }
 
 /* used when colorizing ON4KST chat prompt */
-static gboolean 
+static gboolean
 findrightarrowprompt (gunichar ch, gpointer user_data)
 {
   switch (ch)
@@ -448,7 +480,7 @@ findrightarrowprompt (gunichar ch, gpointer user_data)
 }
 
 /* used when colorizing all prompts */
-static gboolean 
+static gboolean
 findpromptspace (gunichar ch, gpointer user_data)
 {
   switch (ch)
@@ -512,12 +544,12 @@ maintext_add (gchar msg[], gint len, gint messagetype)
       while ((msg = extractinfo(msg)))
       {
       if (dx->dx)
-      { 
+      {
         g_strstrip(dx->freq);
         g_strstrip(dx->remark);
         gtk_tree_store_append (model, &iter, NULL);
         gtk_tree_store_set (model, &iter, FROM_COLUMN, dx->spotter, FREQ_COLUMN,
-  	  dx->freq, DX_COLUMN, dx->dxcall, TIME_COLUMN, dx->time, INFO_COLUMN, 
+  	  dx->freq, DX_COLUMN, dx->dxcall, TIME_COLUMN, dx->time, INFO_COLUMN,
           dx->info, COUNTRY_COLUMN, dx->country, -1);
         /* remark field may contain foreign language characters */
         if (dx->remark && dx->remark[0] && (utf8 = try_utf8(dx->remark)))
@@ -527,8 +559,8 @@ maintext_add (gchar msg[], gint len, gint messagetype)
         }
 
 
-        /* focusing the treeview will stop scrolling */ 
-	if (!GTK_WIDGET_HAS_FOCUS(treeview))
+        /* focusing the treeview will stop scrolling */
+	if (!gtk_widget_has_focus(treeview))
         {
           path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), &iter);
           gtk_tree_view_set_cursor (GTK_TREE_VIEW (treeview), path, NULL, FALSE);
@@ -545,7 +577,7 @@ maintext_add (gchar msg[], gint len, gint messagetype)
 	g_free(dx->country);
         g_free(dx->info);
       }
-      if (dx->nodx)  
+      if (dx->nodx)
       {
         if ((!g_ascii_strncasecmp (dx->toall, "WWV de ", 6)
             || !g_ascii_strncasecmp (dx->toall, "WCY de ", 6))
@@ -778,7 +810,7 @@ maintext_add (gchar msg[], gint len, gint messagetype)
                 while (gtk_text_iter_backward_search (&end, s->str,
                   GTK_TEXT_SEARCH_VISIBLE_ONLY|GTK_TEXT_SEARCH_TEXT_ONLY,
                   &smatch, &ematch, NULL))
-                {      
+                {
                   swidget = gtk_image_new_from_file (s->file);
                   gtk_text_buffer_delete (buffer, &smatch, &ematch);
                   anchor = gtk_text_buffer_create_child_anchor (buffer, &smatch);
@@ -797,7 +829,7 @@ maintext_add (gchar msg[], gint len, gint messagetype)
           }
         }
         /* focusing (clicking) the textview will stop scrolling */
-	if (!GTK_WIDGET_HAS_FOCUS(maintext))
+	if (!gtk_widget_has_focus(maintext))
 	{
           gtk_text_buffer_get_bounds (buffer, &start, &end);
           gtk_text_buffer_place_cursor(buffer, &end);
@@ -814,7 +846,7 @@ maintext_add (gchar msg[], gint len, gint messagetype)
     {
       if (msg && msg[0] && (utf8 = try_utf8(msg)))
       {
-          gtk_text_buffer_insert_with_tags_by_name 
+          gtk_text_buffer_insert_with_tags_by_name
             (buffer, &end, utf8, len, gui->senttagname, NULL);
           g_free (utf8);
       }
@@ -1029,24 +1061,78 @@ dxcc_add (gchar *c, gint w, gint i, gchar *cont, gint lat, gint lon,
 	g_ptr_array_add (dxcc, new_dxcc);
 }
 
-/* fill the hashtable with all of the prefixes from cty.dat */
+
+/* fill the hashtable with all of the prefixes from cty.dat
+ *
+ * Country file format:
+ * http://www.country-files.com/cty/backup/format.htm
+ *
+ */
 gint
 readctydata (void)
 {
-
-	gchar buf[4096], *cty_location, *pfx, **split, **pfxsplit, *excstr;
-	gint ichar = 0, dxccitem = 0, ipfx = 0, ch = 0;
+	gchar buf[MAX_RECORD_SIZE], *cty_location, *pfx, **split, **pfxsplit,
+	      *excstr, *cty_env;
+	gint ichar = 0, dxccitem = 0, ipfx = 0, ch = 0, errsv;
+	extern gchar *opt_cty_path;
 	FILE *fp;
-	
-	cty_location = g_strdup_printf ("%s%s%s", PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S, "cty.dat");
+	GStatBuf statcty;
 
-	if ((fp = fopen (cty_location, "r")) == NULL)
-	{
-		printf("Cannot find cty.dat in %s !\n",cty_location);
+	/* Check for user specification of the location of the country file
+	 * "cty.dat" in the following order:
+	 * 1. via command line with the -c or --cty_dat options
+	 * 2. via the environment with the XDX_CTY variable
+	 *
+	 * Fall back to:
+	 * 1. preferencesdir/cty.dat
+	 * 2. installed version of cty.dat
+	 */
+
+	/* Check if user passed cty.dat path on command line.*/
+	if (opt_cty_path != NULL && g_str_has_suffix(opt_cty_path, "cty.dat")) {
+		cty_location = g_strdup_printf("%s", opt_cty_path);
+
+		g_free(opt_cty_path);
+	} else {
+		/* Support user setting of environment variable XDX_CTY for
+		 * specific location of cty.dat.
+		 */
+		cty_env = getenv("XDX_CTY");
+
+		/* It's most likely that XDX_CTY will not be set. */
+		if (cty_env != NULL && g_str_has_suffix(cty_env, "cty.dat")) {
+			cty_location = g_strdup_printf("%s", cty_env);
+		} else {
+			/* $HOME/.xdx/cty.dat */
+			cty_location = g_strdup_printf("%s%s%s", gui->preferencesdir,
+						       G_DIR_SEPARATOR_S, "cty.dat");
+		}
+	}
+
+	errsv = g_stat(cty_location, &statcty);
+
+	/* Check if --cty_dat, XDX_CTY, or $HOME/.xdx/cty.dat exists. */
+	if (!S_ISREG(statcty.st_mode)) {
+		if (errsv == -1) {
+			g_printerr(_("%s: %s\n"), g_strerror(errno), cty_location );
+		}
+
+		g_free(cty_location);
+
+		/* Fall back to installed cty.dat */
+		cty_location = g_strdup_printf("%s%s%s", PACKAGE_DATA_DIR,
+					        G_DIR_SEPARATOR_S, "cty.dat");
+	}
+
+	if ((fp = fopen (cty_location, "r")) == NULL) {
+		g_printerr(_("Cannot read cty.dat in %s\n"), cty_location);
 		g_free (cty_location);
+
 		return (1);
 	}
 
+	g_print(_("Loading %s\n"), cty_location);
+
 	dxcc = g_ptr_array_new ();
 	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal,
 		(GDestroyNotify)g_free, NULL);
@@ -1055,9 +1141,13 @@ readctydata (void)
 	dxcc_add ("Unknown", 0, 0, "--", 0, 0, 0, "", "");
 	countries = 1;
 
-	while (!feof (fp))
+    /* Read the CTY.DAT file. */
+	while (!feof(fp))
 	{
-		while (ch != 59)
+        /* Check for ';' record terminator.
+         * Avoid buffer overrun of any single record.
+         */
+		while (ch != 59 && ichar < MAX_RECORD_SIZE)
 		{
 			ch = fgetc (fp);
 			if (ch == EOF) break;
@@ -1133,4 +1223,3 @@ cleanup_dxcc (void)
 	}
 	if (prefixes) g_hash_table_destroy (prefixes);
 }
-
